Struct compiletest_rs::common::Config [−][src]
pub struct Config {
pub compile_lib_path: PathBuf,
pub run_lib_path: PathBuf,
pub rustc_path: PathBuf,
pub rustdoc_path: Option<PathBuf>,
pub lldb_python: String,
pub docck_python: String,
pub llvm_filecheck: Option<PathBuf>,
pub valgrind_path: Option<String>,
pub force_valgrind: bool,
pub src_base: PathBuf,
pub build_base: PathBuf,
pub stage_id: String,
pub mode: Mode,
pub run_ignored: bool,
pub filter: Option<String>,
pub filter_exact: bool,
pub logfile: Option<PathBuf>,
pub runtool: Option<String>,
pub host_rustcflags: Option<String>,
pub target_rustcflags: Option<String>,
pub target: String,
pub host: String,
pub gdb: Option<String>,
pub gdb_version: Option<u32>,
pub gdb_native_rust: bool,
pub lldb_version: Option<String>,
pub llvm_version: Option<String>,
pub system_llvm: bool,
pub android_cross_path: PathBuf,
pub adb_path: String,
pub adb_test_dir: String,
pub adb_device_status: bool,
pub lldb_python_dir: Option<String>,
pub verbose: bool,
pub quiet: bool,
pub color: ColorConfig,
pub remote_test_client: Option<PathBuf>,
pub cc: String,
pub cxx: String,
pub cflags: String,
pub ar: String,
pub linker: Option<String>,
pub llvm_components: String,
pub llvm_cxxflags: String,
pub nodejs: Option<String>,
}Fields
compile_lib_path: PathBuf
The library paths required for running the compiler
run_lib_path: PathBuf
The library paths required for running compiled programs
rustc_path: PathBuf
The rustc executable
rustdoc_path: Option<PathBuf>
The rustdoc executable
lldb_python: String
The python executable to use for LLDB
docck_python: String
The python executable to use for htmldocck
llvm_filecheck: Option<PathBuf>
The llvm FileCheck binary path
valgrind_path: Option<String>
The valgrind path
force_valgrind: bool
Whether to fail if we can't run run-pass-valgrind tests under valgrind (or, alternatively, to silently run them like regular run-pass tests).
src_base: PathBuf
The directory containing the tests to run
build_base: PathBuf
The directory where programs should be built
stage_id: String
The name of the stage being built (stage1, etc)
mode: Mode
The test mode, compile-fail, run-fail, run-pass
run_ignored: bool
Run ignored tests
filter: Option<String>
Only run tests that match this filter
filter_exact: bool
Exactly match the filter, rather than a substring
logfile: Option<PathBuf>
Write out a parseable log of tests that were run
runtool: Option<String>
A command line to prefix program execution with, for running under valgrind
host_rustcflags: Option<String>
Flags to pass to the compiler when building for the host
target_rustcflags: Option<String>
Flags to pass to the compiler when building for the target
target: String
Target system to be tested
host: String
Host triple for the compiler being invoked
gdb: Option<String>
Path to / name of the GDB executable
gdb_version: Option<u32>
Version of GDB, encoded as ((major * 1000) + minor) * 1000 + patch
gdb_native_rust: bool
Whether GDB has native rust support
lldb_version: Option<String>
Version of LLDB
llvm_version: Option<String>
Version of LLVM
system_llvm: bool
Is LLVM a system LLVM
android_cross_path: PathBuf
Path to the android tools
adb_path: String
Extra parameter to run adb on arm-linux-androideabi
adb_test_dir: String
Extra parameter to run test suite on arm-linux-androideabi
adb_device_status: bool
status whether android device available or not
lldb_python_dir: Option<String>
the path containing LLDB's Python module
verbose: bool
Explain what's going on
quiet: bool
Print one character per test instead of one line
color: ColorConfig
Whether to use colors in test.
remote_test_client: Option<PathBuf>
where to find the remote test client process, if we're using it
cc: String
cxx: String
cflags: String
ar: String
linker: Option<String>
llvm_components: String
llvm_cxxflags: String
nodejs: Option<String>
Methods
impl Config[src]
impl Configpub fn parse_name_value_directive(
&self,
line: &str,
directive: &str
) -> Option<String>[src]
pub fn parse_name_value_directive(
&self,
line: &str,
directive: &str
) -> Option<String>pub fn find_rust_src_root(&self) -> Option<PathBuf>[src]
pub fn find_rust_src_root(&self) -> Option<PathBuf>impl Config[src]
impl Configpub fn link_deps(&mut self)[src]
pub fn link_deps(&mut self)Add rustc flags to link with the crate's dependencies in addition to the crate itself
pub fn clean_rmeta(&self)[src]
pub fn clean_rmeta(&self)Remove rmeta files from target deps directory
These files are created by cargo check, and conflict with
cargo build rlib files, causing E0464 for tests which use
the parent crate.